#
# spec file for package gammastep
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __requires_exclude typelib\\(AppIndicator3\\)
Name:           gammastep
Version:        2.0.9
Release:        2.3
Summary:        Adjusts the color temperature of your screen according to time of day
License:        0BSD AND GPL-3.0-or-later AND MIT
URL:            https://gitlab.com/chinstrap/gammastep
Source0:        %{url}/-/archive/v%{version}/%{name}-v%{version}.tar.gz
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-devel >= 3.2
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(gio-2.0) >= 2.26
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-scanner) >= 1.15.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       hicolor-icon-theme

%description
Gammastep adjusts the color temperature of your screen according to your
surroundings. This may help your eyes hurt less if you are working in front
of the screen at night.

The color temperature is set according to the position of the sun. A different
color temperature is set during night and daytime. During twilight and early
morning, the color temperature transitions smoothly from night to daytime
temperature to allow your eyes to slowly adapt.

Gammastep supports wlr-gamma-control-unstable-v1 protocol for wlroots-based
wayland compositors.

%package        indicator
Summary:        GTK indicator applet for %{name}
Requires:       python3dist(pygobject)
Requires:       python3dist(pyxdg)

%description    indicator
This package provides a status icon for %{name} that allows the user
to control color temperature.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
./bootstrap
%configure \
    --with-systemduserunitdir=%{_userunitdir}
%make_build

%install
%make_install
sed -i 's|/env python3|/python3|' %{buildroot}%{_bindir}/%{name}-indicator
%find_lang %{name}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

%post
%systemd_user_post %{name}.service

%post indicator
%systemd_user_post %{name}-indicator.service

%preun
%systemd_user_preun %{name}.service

%preun indicator
%systemd_user_preun %{name}-indicator.service

%files -f %{name}.lang
%license COPYING
%doc README.md %{name}.conf.sample
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_userunitdir}/%{name}.service

%files indicator
%{_bindir}/%{name}-indicator
%{_datadir}/applications/%{name}-indicator.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}-status-*.svg
%{_datadir}/metainfo/%{name}-indicator.appdata.xml
%{_userunitdir}/%{name}-indicator.service
%{python3_sitelib}/%{name}_indicator/

%changelog
* Tue Sep 19 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of license based on legaldb report
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.9:
  * fix: wayland: avoid memory leak
  * fix: wayland: recover from failure due to VT switch
* Wed Mar 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add gobject-introspection BuildRequires: allow pygobject to
  inspect the py files and add auto-deps to the relevant
  typelib()s. Filter auto-detected typelib(AppIndicator3): The code
  handles AppIndicator and AyatanaAppIndicator. We only want to
  require one of the two.
- Drop gtk3 Requires: this is auto-detected by the dep scanner.
- Drop hard dependency on systemd: the systemd user service macros
  cope with the absence of systemd.
* Wed Mar 16 2022 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to v2.0.8
  * Fix '-q' option
  * Fix typo in AppArmor profile name
* Mon Feb  8 2021 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to v2.0.7
  * Escape error text in indicator dialog
  * Downgrade wlroots method error to warning
  * Update turkish translations
* Fri Jan  8 2021 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Update to v2.0.6 (2020-11-14)
  * Update AppData metadata for modern practices (again)
  * Update pt_BR translations
  * Add wayland abstraction to AppArmor profile
  * Use AyatanaAppIndicator library when available
- Update to v2.0.5 (2020-11-14)
  * Undo AppData updates from version 2.0.4
- Update to v2.0.4 (2020-11-14)
  * Update AppData metadata for modern practices
  * Add keywords to desktop file
- Update to v2.0.3 (2020-11-11)
  * Fix indicator for new logging methodology
  * Fix logging in print mode
  * Add more error logging for wl method
  * Update README and CONTRIBUTING docs
* Fri Oct 23 2020 Martin Sirringhaus <martin.sirringhaus@suse.com>
- Initial commit of v2.0.2 using minimally adjusted spec-file
  provided by upstream
